@@ -8,12 +8,14 @@ To read project metadata, consider using
 For simple scenarios, you can also try parsing the file directly
 with the help of ``tomllib`` or ``tomli``.
 """
+
 import logging
 import os
 from contextlib import contextmanager
 from functools import partial
-from typing import TYPE_CHECKING, Callable, Dict, Mapping, Optional, Set, Union
+from typing import TYPE_CHECKING, Callable, Dict, Mapping, Optional, Set
 
+from .._path import StrPath
 from ..errors import FileError, InvalidConfigError
 from ..warnings import SetuptoolsWarning
 from . import expand as _expand
@@ -22,19 +24,19 @@ from ._apply_pyprojecttoml import apply as _apply
 
 if TYPE_CHECKING:
     from setuptools.dist import Distribution  # noqa
+    from typing_extensions import Self
 
-_Path = Union[str, os.PathLike]
 _logger = logging.getLogger(__name__)
 
 
-def load_file(filepath: _Path) -> dict:
-    import tomli  # type: ignore
+def load_file(filepath: StrPath) -> dict:
+    from ..compat.py310 import tomllib
 
     with open(filepath, "rb") as file:
-        return tomli.load(file)
+        return tomllib.load(file)
 
 
-def validate(config: dict, filepath: _Path) -> bool:
+def validate(config: dict, filepath: StrPath) -> bool:
     import validate_pyproject.api, validate_pyproject.errors, validate_pyproject.cli, validate_pyproject.plugins
 
     trove_classifier = validate_pyproject.api.FORMAT_FUNCTIONS.get("trove-classifier")
@@ -63,7 +65,7 @@ def validate(config: dict, filepath: _Path) -> bool:
 
 def apply_configuration(
     dist: "Distribution",
-    filepath: _Path,
+    filepath: StrPath,
     ignore_option_errors=False,
 ) -> "Distribution":
     """Apply the configuration from a ``pyproject.toml`` file into an existing
@@ -74,7 +76,7 @@ def apply_configuration(
 
 
 def read_configuration(
-    filepath: _Path,
+    filepath: StrPath,
     expand=True,
     ignore_option_errors=False,
     dist: Optional["Distribution"] = None,
@@ -141,7 +143,7 @@ def read_configuration(
 
 def expand_configuration(
     config: dict,
-    root_dir: Optional[_Path] = None,
+    root_dir: Optional[StrPath] = None,
     ignore_option_errors: bool = False,
     dist: Optional["Distribution"] = None,
 ) -> dict:
@@ -166,7 +168,7 @@ class _ConfigExpander:
     def __init__(
         self,
         config: dict,
-        root_dir: Optional[_Path] = None,
+        root_dir: Optional[StrPath] = None,
         ignore_option_errors: bool = False,
         dist: Optional["Distribution"] = None,
     ):
@@ -276,7 +278,7 @@ class _ConfigExpander:
     def _expand_directive(
         self, specifier: str, directive, package_dir: Mapping[str, str]
     ):
-        from more_itertools import always_iterable  # type: ignore
+        from more_itertools import always_iterable
 
         with _ignore_errors(self.ignore_option_errors):
             root_dir = self.root_dir
@@ -406,7 +408,7 @@ class _EnsurePackagesDiscovered(_expand.EnsurePackagesDiscovered):
         self._project_cfg = project_cfg
         self._setuptools_cfg = setuptools_cfg
 
-    def __enter__(self):
+    def __enter__(self) -> "Self":
         """When entering the context, the values of ``packages``, ``py_modules`` and
         ``package_dir`` that are missing in ``dist`` are copied from ``setuptools_cfg``.
         """
